@@ -84,7 +84,7 @@ def repo_dump(node, output_directory):
     The output directory should not exist. If it does, the command
     will abort.
     """
-    from aiida.orm.utils.repository import FileType
+    from aiida.repository import FileType
 
     output_directory = pathlib.Path(output_directory)
 
@@ -98,18 +98,18 @@ def repo_dump(node, output_directory):
         Recursively copy the content at the ``key`` path in the given node to
         the ``output_dir``.
         """
-        for file in node.list_objects(key=key):
+        for file in node.list_objects(key):
             # Not using os.path.join here, because this is the "path"
             # in the AiiDA node, not an actual OS - level path.
             file_key = file.name if not key else key + '/' + file.name
-            if file.type == FileType.DIRECTORY:
+            if file.file_type == FileType.DIRECTORY:
                 new_out_dir = output_dir / file.name
                 assert not new_out_dir.exists()
                 new_out_dir.mkdir()
                 _copy_tree(key=file_key, output_dir=new_out_dir)
 
             else:
-                assert file.type == FileType.FILE
+                assert file.file_type == FileType.FILE
                 out_file_path = output_dir / file.name
                 assert not out_file_path.exists()
                 with node.open(file_key, 'rb') as in_file:
