@@ -30,15 +30,19 @@ def type_check(what, of_type, msg=None, allow_none=False):
     :param of_type: the type (or tuple of types) to compare to
     :param msg: if specified, allows to customize the message that is passed within the TypeError exception
     :param allow_none: boolean, if True will not raise if the passed `what` is `None`
+
+    :return: `what` or `None`
     """
     if allow_none and what is None:
-        return
+        return None
 
     if not isinstance(what, of_type):
         if msg is None:
             msg = "Got object of type '{}', expecting '{}'".format(type(what), of_type)
         raise TypeError(msg)
 
+    return what
+
 
 def override_decorator(check=False):
     """Decorator to signal that a method from a base class is being overridden completely."""
