@@ -41,6 +41,13 @@ class Profile:  # pylint: disable=too-many-public-methods
     KEY_DATABASE_HOSTNAME = 'AIIDADB_HOST'
     KEY_DATABASE_USERNAME = 'AIIDADB_USER'
     KEY_DATABASE_PASSWORD = 'AIIDADB_PASS'  # noqa
+    KEY_BROKER_PROTOCOL = 'broker_protocol'
+    KEY_BROKER_USERNAME = 'broker_username'
+    KEY_BROKER_PASSWORD = 'broker_password'  # noqa
+    KEY_BROKER_HOST = 'broker_host'
+    KEY_BROKER_PORT = 'broker_port'
+    KEY_BROKER_VIRTUAL_HOST = 'broker_virtual_host'
+    KEY_BROKER_PARAMETERS = 'broker_parameters'
     KEY_REPOSITORY_URI = 'AIIDADB_REPOSITORY_URI'
 
     # A mapping of valid attributes to the key under which they are stored in the configuration dictionary
@@ -55,6 +62,13 @@ class Profile:  # pylint: disable=too-many-public-methods
         KEY_DATABASE_HOSTNAME: 'database_hostname',
         KEY_DATABASE_USERNAME: 'database_username',
         KEY_DATABASE_PASSWORD: 'database_password',
+        KEY_BROKER_PROTOCOL: 'broker_protocol',
+        KEY_BROKER_USERNAME: 'broker_username',
+        KEY_BROKER_PASSWORD: 'broker_password',
+        KEY_BROKER_HOST: 'broker_host',
+        KEY_BROKER_PORT: 'broker_port',
+        KEY_BROKER_VIRTUAL_HOST: 'broker_virtual_host',
+        KEY_BROKER_PARAMETERS: 'broker_parameters',
         KEY_REPOSITORY_URI: 'repository_uri',
     }
 
@@ -175,6 +189,62 @@ class Profile:  # pylint: disable=too-many-public-methods
     def database_password(self, value):
         self._attributes[self.KEY_DATABASE_PASSWORD] = value
 
+    @property
+    def broker_protocol(self):
+        return self._attributes[self.KEY_BROKER_PROTOCOL]
+
+    @broker_protocol.setter
+    def broker_protocol(self, value):
+        self._attributes[self.KEY_BROKER_PROTOCOL] = value
+
+    @property
+    def broker_host(self):
+        return self._attributes[self.KEY_BROKER_HOST]
+
+    @broker_host.setter
+    def broker_host(self, value):
+        self._attributes[self.KEY_BROKER_HOST] = value
+
+    @property
+    def broker_port(self):
+        return self._attributes[self.KEY_BROKER_PORT]
+
+    @broker_port.setter
+    def broker_port(self, value):
+        self._attributes[self.KEY_BROKER_PORT] = value
+
+    @property
+    def broker_username(self):
+        return self._attributes[self.KEY_BROKER_USERNAME]
+
+    @broker_username.setter
+    def broker_username(self, value):
+        self._attributes[self.KEY_BROKER_USERNAME] = value
+
+    @property
+    def broker_password(self):
+        return self._attributes[self.KEY_BROKER_PASSWORD]
+
+    @broker_password.setter
+    def broker_password(self, value):
+        self._attributes[self.KEY_BROKER_PASSWORD] = value
+
+    @property
+    def broker_virtual_host(self):
+        return self._attributes[self.KEY_BROKER_VIRTUAL_HOST]
+
+    @broker_virtual_host.setter
+    def broker_virtual_host(self, value):
+        self._attributes[self.KEY_BROKER_VIRTUAL_HOST] = value
+
+    @property
+    def broker_parameters(self):
+        return self._attributes.get(self.KEY_BROKER_PARAMETERS, {})
+
+    @broker_parameters.setter
+    def broker_parameters(self, value):
+        self._attributes[self.KEY_BROKER_PARAMETERS] = value
+
     @property
     def repository_uri(self):
         return self._attributes[self.KEY_REPOSITORY_URI]
@@ -268,6 +338,18 @@ class Profile:  # pylint: disable=too-many-public-methods
 
         return parts.scheme, os.path.expanduser(parts.path)
 
+    def get_rmq_url(self):
+        from aiida.manage.external.rmq import get_rmq_url
+        return get_rmq_url(
+            protocol=self.broker_protocol,
+            username=self.broker_username,
+            password=self.broker_password,
+            host=self.broker_host,
+            port=self.broker_port,
+            virtual_host=self.broker_virtual_host,
+            **self.broker_parameters
+        )
+
     def configure_repository(self):
         """Validates the configured repository and in the case of a file system repo makes sure the folder exists."""
         import errno
