@@ -8,15 +8,14 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Module for Computer entities"""
-
 import logging
 import os
 import warnings
 
-from aiida import transports, schedulers
 from aiida.common import exceptions
 from aiida.common.warnings import AiidaDeprecationWarning
 from aiida.manage.manager import get_manager
+from aiida.orm.implementation import Backend
 from aiida.plugins import SchedulerFactory, TransportFactory
 
 from . import entities
@@ -51,33 +50,72 @@ class Computer(entities.Entity):
     class Collection(entities.Collection):
         """The collection of Computer entries."""
 
+        def get(self, **filters):
+            """Get a single collection entry that matches the filter criteria.
+
+            :param filters: the filters identifying the object to get
+            :type filters: dict
+
+            :return: the entry
+            """
+            if 'name' in filters:
+                warnings.warn('keyword `name` is deprecated, use `label` instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+
+            # This switch needs to be here until we fully remove `name` and replace it with `label` even on the backend
+            # entities and database models.
+            if 'label' in filters:
+                filters['name'] = filters.pop('label')
+
+            return super().get(**filters)
+
         def list_names(self):
-            """Return a list with all the names of the computers in the DB."""
+            """Return a list with all the names of the computers in the DB.
+
+            .. deprecated:: 1.4.0
+                Will be removed in `v2.0.0`, use `list_labels` instead.
+            """
+            return self._backend.computers.list_names()
+
+        def list_labels(self):
+            """Return a list with all the labels of the computers in the DB."""
             return self._backend.computers.list_names()
 
         def delete(self, id):  # pylint: disable=redefined-builtin,invalid-name
             """Delete the computer with the given id"""
             return self._backend.computers.delete(id)
 
-    def __init__(
-        self, name, hostname, description='', transport_type='', scheduler_type='', workdir=None, backend=None
-    ):
+    def __init__(  # pylint: disable=too-many-arguments
+        self,
+        label: str = None,
+        hostname: str = None,
+        description: str = '',
+        transport_type: str = '',
+        scheduler_type: str = '',
+        workdir: str = None,
+        backend: Backend = None,
+        name: str = None
+    ) -> 'Computer':
         """Construct a new computer
 
-        :type name: str
-        :type hostname: str
-        :type description: str
-        :type transport_type: str
-        :type scheduler_type: str
-        :type workdir: str
-        :type backend: :class:`aiida.orm.implementation.Backend`
-
-        :rtype: :class:`aiida.orm.Computer`
+            .. deprecated:: 1.4.0
+                The `name` keyword will be removed in `v2.0.0`, use `label` instead.
         """
-        # pylint: disable=too-many-arguments
+
+        # This needs to be here because `label` needed to get a default, since it was replacing `name` and during the
+        # deprecation period, it needs to be automatically set to whatever `name` is passed. As a knock-on effect, since
+        # a keyword argument cannot preceed a normal argument, `hostname` also needed to become a keyword argument,
+        # forcing us to set a default, which we set to `None`. We raise the same exception that Python would normally
+        # raise if a normally positional argument is not specified.
+        if hostname is None:
+            raise TypeError("missing 1 required positional argument: 'hostname'")
+
+        if name is not None:
+            warnings.warn('keyword `name` is deprecated, use `label` instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+            label = name
+
         backend = backend or get_manager().get_backend()
         model = backend.computers.create(
-            name=name,
+            name=label,
             hostname=hostname,
             description=description,
             transport_type=transport_type,
@@ -91,23 +129,27 @@ class Computer(entities.Entity):
         return '<{}: {}>'.format(self.__class__.__name__, str(self))
 
     def __str__(self):
-        return '{} ({}), pk: {}'.format(self.name, self.hostname, self.pk)
+        return '{} ({}), pk: {}'.format(self.label, self.hostname, self.pk)
 
     @property
     def full_text_info(self):
         """
         Return a (multiline) string with a human-readable detailed information on this computer.
 
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`.
+
         :rtype: str
         """
+        warnings.warn('this property is deprecated', AiidaDeprecationWarning)  # pylint: disable=no-member
         ret_lines = []
-        ret_lines.append('Computer name:     {}'.format(self.name))
+        ret_lines.append('Computer name:     {}'.format(self.label))
         ret_lines.append(' * PK:             {}'.format(self.pk))
         ret_lines.append(' * UUID:           {}'.format(self.uuid))
         ret_lines.append(' * Description:    {}'.format(self.description))
         ret_lines.append(' * Hostname:       {}'.format(self.hostname))
-        ret_lines.append(' * Transport type: {}'.format(self.get_transport_type()))
-        ret_lines.append(' * Scheduler type: {}'.format(self.get_scheduler_type()))
+        ret_lines.append(' * Transport type: {}'.format(self.transport_type))
+        ret_lines.append(' * Scheduler type: {}'.format(self.scheduler_type))
         ret_lines.append(' * Work directory: {}'.format(self.get_workdir()))
         ret_lines.append(' * Shebang:        {}'.format(self.get_shebang()))
         ret_lines.append(' * mpirun command: {}'.format(' '.join(self.get_mpirun_command())))
@@ -137,8 +179,6 @@ class Computer(entities.Entity):
     def logger(self):
         return self._logger
 
-    # region validation
-
     @classmethod
     def _name_validator(cls, name):
         """
@@ -167,7 +207,8 @@ class Computer(entities.Entity):
         """
         Validates the transport string.
         """
-        if transport_type not in transports.Transport.get_valid_transports():
+        from aiida.plugins.entry_point import get_entry_point_names
+        if transport_type not in get_entry_point_names('aiida.transports'):
             raise exceptions.ValidationError('The specified transport is not a valid one')
 
     @classmethod
@@ -175,7 +216,8 @@ class Computer(entities.Entity):
         """
         Validates the transport string.
         """
-        if scheduler_type not in schedulers.Scheduler.get_valid_schedulers():
+        from aiida.plugins.entry_point import get_entry_point_names
+        if scheduler_type not in get_entry_point_names('aiida.schedulers'):
             raise exceptions.ValidationError('The specified scheduler is not a valid one')
 
     @classmethod
@@ -245,13 +287,13 @@ class Computer(entities.Entity):
         For the base class, this is always valid. Subclasses will reimplement this.
         In the subclass, always call the super().validate() method first!
         """
-        if not self.get_name().strip():
+        if not self.label.strip():
             raise exceptions.ValidationError('No name specified')
 
-        self._hostname_validator(self.get_hostname())
-        self._description_validator(self.get_description())
-        self._transport_type_validator(self.get_transport_type())
-        self._scheduler_type_validator(self.get_scheduler_type())
+        self._hostname_validator(self.hostname)
+        self._description_validator(self.description)
+        self._transport_type_validator(self.transport_type)
+        self._scheduler_type_validator(self.scheduler_type)
         self._workdir_validator(self.get_workdir())
 
         try:
@@ -272,14 +314,10 @@ class Computer(entities.Entity):
 
         if not isinstance(def_cpus_per_machine, int) or def_cpus_per_machine <= 0:
             raise exceptions.ValidationError(
-                'Invalid value for default_mpiprocs_per_machine, '
-                'must be a positive integer, or an empty '
-                'string if you do not want to provide a '
-                'default value.'
+                'Invalid value for default_mpiprocs_per_machine, must be a positive integer, or an empty string if you '
+                'do not want to provide a default value.'
             )
 
-    # endregion
-
     def copy(self):
         """
         Return a copy of the current object to work with, not stored yet.
@@ -297,49 +335,100 @@ class Computer(entities.Entity):
         return super().store()
 
     @property
-    def name(self):
+    def label(self) -> str:
+        """Return the computer label.
+
+        :return: the label.
+        """
         return self._backend_entity.name
 
-    @property
-    def label(self):
-        """
-        The computer label
-        """
-        return self.name
-
     @label.setter
-    def label(self, value):
+    def label(self, value: str):
+        """Set the computer label.
+
+        :param value: the label to set.
         """
-        Set the computer label (i.e., name)
-        """
-        self.set_name(value)
+        self._backend_entity.set_name(value)
 
     @property
-    def description(self):
-        """
-        Get a description of the computer
+    def description(self) -> str:
+        """Return the computer computer.
 
-        :return: the description
-        :rtype: str
+        :return: the description.
         """
         return self._backend_entity.description
 
+    @description.setter
+    def description(self, value: str):
+        """Set the computer description.
+
+        :param value: the description to set.
+        """
+        self._backend_entity.set_description(value)
+
     @property
-    def hostname(self):
+    def hostname(self) -> str:
+        """Return the computer hostname.
+
+        :return: the hostname.
+        """
         return self._backend_entity.hostname
 
-    def get_metadata(self):
+    @hostname.setter
+    def hostname(self, value: str):
+        """Set the computer hostname.
+
+        :param value: the hostname to set.
+        """
+        self._backend_entity.set_hostname(value)
+
+    @property
+    def scheduler_type(self) -> str:
+        """Return the computer scheduler type.
+
+        :return: the scheduler type.
+        """
+        return self._backend_entity.get_scheduler_type()
+
+    @scheduler_type.setter
+    def scheduler_type(self, value: str):
+        """Set the computer scheduler type.
+
+        :param value: the scheduler type to set.
+        """
+        self._backend_entity.set_scheduler_type(value)
+
+    @property
+    def transport_type(self) -> str:
+        """Return the computer transport type.
+
+        :return: the transport_type.
+        """
+        return self._backend_entity.get_transport_type()
+
+    @transport_type.setter
+    def transport_type(self, value: str):
+        """Set the computer transport type.
+
+        :param value: the transport_type to set.
+        """
+        self._backend_entity.set_transport_type(value)
+
+    @property
+    def metadata(self) -> str:
+        """Return the computer metadata.
+
+        :return: the metadata.
+        """
         return self._backend_entity.get_metadata()
 
-    def set_metadata(self, metadata):
-        """
-        Set the metadata.
+    @metadata.setter
+    def metadata(self, value: str):
+        """Set the computer metadata.
 
-        .. note: You still need to call the .store() method to actually save
-           data to the database! (The store method can be called multiple
-           times, differently from AiiDA Node objects).
+        :param value: the metadata to set.
         """
-        self._backend_entity.set_metadata(metadata)
+        self._backend_entity.set_metadata(value)
 
     def delete_property(self, name, raise_exception=True):
         """
@@ -351,10 +440,10 @@ class Computer(entities.Entity):
         :param raise_exception: if True raise if the property does not exist, otherwise return None
         :type raise_exception: bool
         """
-        olddata = self.get_metadata()
+        olddata = self.metadata
         try:
             del olddata[name]
-            self.set_metadata(olddata)
+            self.metadata = olddata
         except KeyError:
             if raise_exception:
                 raise AttributeError("'{}' property not found".format(name))
@@ -366,9 +455,9 @@ class Computer(entities.Entity):
         :param name: the property name
         :param value: the new value
         """
-        metadata = self.get_metadata() or {}
+        metadata = self.metadata or {}
         metadata[name] = value
-        self.set_metadata(metadata)
+        self.metadata = metadata
 
     def get_property(self, name, *args):
         """
@@ -383,7 +472,7 @@ class Computer(entities.Entity):
         """
         if len(args) > 1:
             raise TypeError('get_property expected at most 2 arguments')
-        olddata = self.get_metadata()
+        olddata = self.metadata
         try:
             return olddata[name]
         except KeyError:
@@ -462,31 +551,6 @@ class Computer(entities.Entity):
         """
         self.set_property(self.PROPERTY_MINIMUM_SCHEDULER_POLL_INTERVAL, interval)
 
-    def get_transport(self, user=None):
-        """
-        Return a Transport class, configured with all correct parameters.
-        The Transport is closed (meaning that if you want to run any operation with
-        it, you have to open it first (i.e., e.g. for a SSH transport, you have
-        to open a connection). To do this you can call ``transports.open()``, or simply
-        run within a ``with`` statement::
-
-           transport = Computer.get_transport()
-           with transport:
-               print(transports.whoami())
-
-        :param user: if None, try to obtain a transport for the default user.
-            Otherwise, pass a valid User.
-
-        :return: a (closed) Transport, already configured with the connection
-            parameters to the supercomputer, as configured with ``verdi computer configure``
-            for the user specified as a parameter ``user``.
-        """
-        from . import authinfos  # pylint: disable=cyclic-import
-
-        user = user or users.User.objects(self.backend).get_default()
-        authinfo = authinfos.AuthInfo.objects(self.backend).get(dbcomputer=self, aiidauser=user)
-        return authinfo.get_transport()
-
     def get_workdir(self):
         """
         Get the working directory for this computer
@@ -509,47 +573,9 @@ class Computer(entities.Entity):
             raise ValueError('{} is invalid. Input has to be a string'.format(val))
         if not val.startswith('#!'):
             raise ValueError('{} is invalid. A shebang line has to start with #!'.format(val))
-        metadata = self.get_metadata()
+        metadata = self.metadata
         metadata['shebang'] = val
-        self.set_metadata(metadata)
-
-    def get_name(self):
-        return self._backend_entity.get_name()
-
-    def set_name(self, val):
-        self._backend_entity.set_name(val)
-
-    def get_hostname(self):
-        """
-        Get this computer hostname
-        :rtype: str
-        """
-        return self._backend_entity.get_hostname()
-
-    def set_hostname(self, val):
-        """
-        Set the hostname of this computer
-        :param val: The new hostname
-        :type val: str
-        """
-        self._backend_entity.set_hostname(val)
-
-    def get_description(self):
-        """
-        Get the description for this computer
-
-        :return: the description
-        :rtype: str
-        """
-
-    def set_description(self, val):
-        """
-        Set the description for this computer
-
-        :param val: the new description
-        :type val: str
-        """
-        self._backend_entity.set_description(val)
+        self.metadata = metadata
 
     def get_authinfo(self, user):
         """
@@ -592,43 +618,33 @@ class Computer(entities.Entity):
             authinfo = self.get_authinfo(user)
             return authinfo.enabled
         except exceptions.NotExistent:
-            # Return False if the user is not configured (in a sense,
-            # it is disabled for that user)
+            # Return False if the user is not configured (in a sense, it is disabled for that user)
             return False
 
-    def get_scheduler_type(self):
+    def get_transport(self, user=None):
         """
-        Get the scheduler type for this computer
+        Return a Transport class, configured with all correct parameters.
+        The Transport is closed (meaning that if you want to run any operation with
+        it, you have to open it first (i.e., e.g. for a SSH transport, you have
+        to open a connection). To do this you can call ``transports.open()``, or simply
+        run within a ``with`` statement::
 
-        :return: the scheduler type
-        :rtype: str
-        """
-        return self._backend_entity.get_scheduler_type()
+           transport = Computer.get_transport()
+           with transport:
+               print(transports.whoami())
 
-    def set_scheduler_type(self, scheduler_type):
-        """
-        :param scheduler_type: the new scheduler type
-        """
-        self._scheduler_type_validator(scheduler_type)
-        self._backend_entity.set_scheduler_type(scheduler_type)
+        :param user: if None, try to obtain a transport for the default user.
+            Otherwise, pass a valid User.
 
-    def get_transport_type(self):
+        :return: a (closed) Transport, already configured with the connection
+            parameters to the supercomputer, as configured with ``verdi computer configure``
+            for the user specified as a parameter ``user``.
         """
-        Get the current transport type for this computer
+        from . import authinfos  # pylint: disable=cyclic-import
 
-        :return: the transport type
-        :rtype: str
-        """
-        return self._backend_entity.get_transport_type()
-
-    def set_transport_type(self, transport_type):
-        """
-        Set the transport type for this computer
-
-        :param transport_type: the new transport type
-        :type transport_type: str
-        """
-        self._backend_entity.set_transport_type(transport_type)
+        user = user or users.User.objects(self.backend).get_default()
+        authinfo = authinfos.AuthInfo.objects(self.backend).get(dbcomputer=self, aiidauser=user)
+        return authinfo.get_transport()
 
     def get_transport_class(self):
         """
@@ -637,12 +653,10 @@ class Computer(entities.Entity):
         :return: the transport class
         """
         try:
-            return TransportFactory(self.get_transport_type())
+            return TransportFactory(self.transport_type)
         except exceptions.EntryPointError as exception:
             raise exceptions.ConfigurationError(
-                'No transport found for {} [type {}], message: {}'.format(
-                    self.name, self.get_transport_type(), exception
-                )
+                'No transport found for {} [type {}], message: {}'.format(self.label, self.transport_type, exception)
             )
 
     def get_scheduler(self):
@@ -653,14 +667,12 @@ class Computer(entities.Entity):
         :rtype: :class:`aiida.schedulers.Scheduler`
         """
         try:
-            scheduler_class = SchedulerFactory(self.get_scheduler_type())
+            scheduler_class = SchedulerFactory(self.scheduler_type)
             # I call the init without any parameter
             return scheduler_class()
         except exceptions.EntryPointError as exception:
             raise exceptions.ConfigurationError(
-                'No scheduler found for {} [type {}], message: {}'.format(
-                    self.name, self.get_scheduler_type(), exception
-                )
+                'No scheduler found for {} [type {}], message: {}'.format(self.label, self.scheduler_type, exception)
             )
 
     def configure(self, user=None, **kwargs):
@@ -720,6 +732,158 @@ class Computer(entities.Entity):
 
         return config
 
+    @property
+    def name(self):
+        """Return the computer name.
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `label` property instead.
+        """
+        warnings.warn('this property is deprecated, use the `label` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.label
+
+    def get_name(self):
+        """Return the computer name.
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `label` property instead.
+        """
+        warnings.warn('this property is deprecated, use the `label` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.label
+
+    def set_name(self, val):
+        """Set the computer name.
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `label` property instead.
+        """
+        warnings.warn('this method is deprecated, use the `label` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self.label = val
+
+    def get_hostname(self):
+        """Get this computer hostname
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `hostname` property instead.
+
+        :rtype: str
+        """
+        warnings.warn('this method is deprecated, use the `hostname` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.hostname
+
+    def set_hostname(self, val):
+        """
+        Set the hostname of this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `hostname` property instead.
+
+        :param val: The new hostname
+        :type val: str
+        """
+        warnings.warn('this method is deprecated, use the `hostname` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self.hostname = val
+
+    def get_description(self):
+        """
+        Get the description for this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `description` property instead.
+
+        :return: the description
+        :rtype: str
+        """
+        warnings.warn('this method is deprecated, use the `description` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.description
+
+    def set_description(self, val):
+        """
+        Set the description for this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `description` property instead.
+
+        :param val: the new description
+        :type val: str
+        """
+        warnings.warn('this method is deprecated, use the `description` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self.description = val
+
+    def get_scheduler_type(self):
+        """
+        Get the scheduler type for this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `scheduler_type` property instead.
+
+        :return: the scheduler type
+        :rtype: str
+        """
+        warnings.warn('this method is deprecated, use the `scheduler_type` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.scheduler_type
+
+    def set_scheduler_type(self, scheduler_type):
+        """
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `scheduler_type` property instead.
+
+        :param scheduler_type: the new scheduler type
+        """
+        warnings.warn('this method is deprecated, use the `scheduler_type` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self._scheduler_type_validator(scheduler_type)
+        self.scheduler_type = scheduler_type
+
+    def get_transport_type(self):
+        """
+        Get the current transport type for this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `transport_type` property instead.
+
+        :return: the transport type
+        :rtype: str
+        """
+        warnings.warn('this method is deprecated, use the `transport_type` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.transport_type
+
+    def set_transport_type(self, transport_type):
+        """
+        Set the transport type for this computer
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `transport_type` property instead.
+
+        :param transport_type: the new transport type
+        :type transport_type: str
+        """
+        warnings.warn('this method is deprecated, use the `transport_type` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self.transport_type = transport_type
+
+    def get_metadata(self):
+        """
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `metadata` property instead.
+
+        """
+        warnings.warn('this method is deprecated, use the `metadata` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        return self.metadata
+
+    def set_metadata(self, metadata):
+        """
+        Set the metadata.
+
+        .. deprecated:: 1.4.0
+            Will be removed in `v2.0.0`, use the `metadata` property instead.
+
+        .. note: You still need to call the .store() method to actually save
+           data to the database! (The store method can be called multiple
+           times, differently from AiiDA Node objects).
+        """
+        warnings.warn('this method is deprecated, use the `metadata` property instead', AiidaDeprecationWarning)  # pylint: disable=no-member
+        self.metadata = metadata
+
     @staticmethod
     def get_schema():
         """
