@@ -84,15 +84,6 @@ class SqlaModelEntity(typing.Generic[ModelType]):
         """
         return self._dbmodel.id
 
-    @property
-    def pk(self):
-        """
-        Get the principal key for this entry
-
-        :return: the principal key
-        """
-        return self._dbmodel.id
-
     @property
     def is_stored(self):
         """
