@@ -41,6 +41,9 @@ class Scheduler(metaclass=abc.ABCMeta):
     # The class to be used for the job resource.
     _job_resource_class = None
 
+    def __str__(self):
+        return self.__class__.__name__
+
     @classmethod
     def preprocess_resources(cls, resources, default_mpiprocs_per_machine=None):
         """Pre process the resources.
@@ -411,3 +414,15 @@ stderr:
 
         :return: True if everything seems ok, False otherwise.
         """
+
+    def parse_output(self, detailed_job_info, stdout, stderr):
+        """Parse the output of the scheduler.
+
+        :param detailed_job_info: dictionary with the output returned by the `Scheduler.get_detailed_job_info` command.
+            This should contain the keys `retval`, `stdout` and `stderr` corresponding to the return value, stdout and
+            stderr returned by the accounting command executed for a specific job id.
+        :param stdout: string with the output written by the scheduler to stdout
+        :param stderr: string with the output written by the scheduler to stderr
+        :return: None or an instance of `aiida.engine.processes.exit_code.ExitCode`
+        """
+        raise exceptions.FeatureNotAvailable('output parsing is not available for `{}`'.format(self.__class__.__name__))
