@@ -9,13 +9,26 @@
 ###########################################################################
 """ Utility functions for export of AiiDA entities """
 # pylint: disable=too-many-locals,too-many-branches,too-many-nested-blocks
+from enum import Enum
+import warnings
 
 from aiida.orm import QueryBuilder, ProcessNode
+from aiida.common.log import AIIDA_LOGGER, LOG_LEVEL_REPORT, override_log_formatter
+from aiida.common.warnings import AiidaDeprecationWarning
+
 from aiida.tools.importexport.common import exceptions
 from aiida.tools.importexport.common.config import (
     file_fields_to_model_fields, entity_names_to_entities, get_all_fields_info
 )
 
+EXPORT_LOGGER = AIIDA_LOGGER.getChild('export')
+
+
+class ExportFileFormat(str, Enum):
+    """Export file formats"""
+    ZIP = 'zip'
+    TAR_GZIPPED = 'tar.gz'
+
 
 def fill_in_query(partial_query, originating_entity_str, current_entity_str, tag_suffixes=None, entity_separator='_'):
     """
@@ -263,11 +276,61 @@ def check_process_nodes_sealed(nodes):
         raise exceptions.ExportValidationError('nodes must be either an int or set/list of ints')
 
     filters = {'id': {'in': nodes}, 'attributes.sealed': True}
-    sealed_nodes = QueryBuilder().append(ProcessNode, filters=filters, project=['id']).all()
-    sealed_nodes = {_[0] for _ in sealed_nodes}
+    sealed_nodes = set(QueryBuilder().append(ProcessNode, filters=filters, project=['id']).all(flat=True))
 
     if sealed_nodes != nodes:
         raise exceptions.ExportValidationError(
             'All ProcessNodes must be sealed before they can be exported. '
             'Node(s) with PK(s): {} is/are not sealed.'.format(', '.join(str(pk) for pk in nodes - sealed_nodes))
         )
+
+
+@override_log_formatter('%(message)s')
+def summary(file_format, outfile, **kwargs):
+    """Print summary for export"""
+    from tabulate import tabulate
+    from aiida.tools.importexport.common.config import EXPORT_VERSION
+
+    parameters = [['Archive', outfile], ['Format', file_format], ['Export version', EXPORT_VERSION]]
+
+    result = '\n{}'.format(tabulate(parameters, headers=['EXPORT', '']))
+
+    include_comments = kwargs.get('include_comments', True)
+    include_logs = kwargs.get('include_logs', True)
+    input_forward = kwargs.get('input_forward', False)
+    create_reversed = kwargs.get('create_reversed', True)
+    return_reversed = kwargs.get('return_reversed', False)
+    call_reversed = kwargs.get('call_reversed', False)
+
+    inclusions = [['Include Comments', include_comments], ['Include Logs', include_logs]]
+    result += '\n\n{}'.format(tabulate(inclusions, headers=['Inclusion rules', '']))
+
+    traversal_rules = [['Follow INPUT Links forwards',
+                        input_forward], ['Follow CREATE Links backwards', create_reversed],
+                       ['Follow RETURN Links backwards', return_reversed],
+                       ['Follow CALL Links backwards', call_reversed]]
+    result += '\n\n{}\n'.format(tabulate(traversal_rules, headers=['Traversal rules', '']))
+
+    EXPORT_LOGGER.log(msg=result, level=LOG_LEVEL_REPORT)
+
+
+def deprecated_parameters(old, new):
+    """Handle deprecated parameter (where it is replaced with another)
+
+    :param old: The old, deprecated parameter as a dict with keys "name" and "value"
+    :type old: dict
+
+    :param new: The new parameter as a dict with keys "name" and "value"
+    :type new: dict
+
+    :return: New parameter's value (if not defined, then old parameter's value)
+    """
+    if old.get('value', None) is not None:
+        if new.get('value', None) is not None:
+            message = '`{}` is deprecated, the supplied `{}` input will be used'.format(old['name'], new['name'])
+        else:
+            message = '`{}` is deprecated, please use `{}` instead'.format(old['name'], new['name'])
+            new['value'] = old['value']
+        warnings.warn(message, AiidaDeprecationWarning)  # pylint: disable=no-member
+
+    return new['value']
